@@ -44,6 +44,8 @@ MailManager::MailManager(QObject *parent)
 
     MailKernel::self();
 
+    connect(&MailKernel::self(), &MailKernel::errorOccurred, this, &MailManager::errorOccurred);
+
     //                              mailModel
     //                                  ^
     //                                  |
@@ -63,6 +65,7 @@ MailManager::MailManager(QObject *parent)
     // setup collection model
     m_entityTreeModel = new Akonadi::EntityTreeModel(folderCollectionMonitor->monitor(), this);
     m_entityTreeModel->setItemPopulationStrategy(Akonadi::EntityTreeModel::LazyPopulation);
+    connect(m_entityTreeModel, &Akonadi::EntityTreeModel::errorOccurred, this, &MailManager::errorOccurred);
 
     auto foldersModel = new Akonadi::CollectionFilterProxyModel(this);
     foldersModel->setSourceModel(m_entityTreeModel);
@@ -220,7 +223,7 @@ void MailManager::saveMail(const QUrl &fileUrl, const Akonadi::Item &item)
 
     auto job = new Akonadi::ItemFetchJob(item);
     job->fetchScope().fetchFullPayload();
-    connect(job, &Akonadi::ItemFetchJob::result, this, [this, filename](KJob *job) {
+    connect(job, &Akonadi::ItemFetchJob::result, this, [filename](KJob *job) {
         const auto *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
         const auto items = fetchJob->items();
         if (items.isEmpty()) {
